# Table of Contents

- [quality-seal](<./quality-seal.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Quality Seal](<./Quality-Seal.md>)
  - [Introduction](<./Quality-Seal/Introduction.md>)
  - [Breaking of Quality Seal](<./Quality-Seal/Breaking-of-Quality-Seal.md>)
  - [Quality Seal States](<./Quality-Seal/Quality-Seal-States.md>)
  - [Quality Seal States of New Fact Sheets](<./Quality-Seal/Quality-Seal-States-of-New-Fact-Sheets.md>)
  - [Approving Fact Sheet Quality](<./Quality-Seal/Approving-Fact-Sheet-Quality.md>)
  - [Enabling or Disabling the Quality Seal](<./Quality-Seal/Enabling-or-Disabling-the-Quality-Seal.md>)
  - [Notifications](<./Quality-Seal/Notifications.md>)
